import React, { useEffect, useState } from 'react';
import { Card, Button, Table, Space, Modal } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { get } from '../../services';
import styles from './ManagementDataBase.less'

const ManagementDataBase = () => {
  const [autoCheckList, setAutoCheckList] = useState([]);
  const [checkList, setCheckList] = useState([]);
  const [logList, setLogList] = useState([]);
  const [checkFlag, setCheckFlag] = useState(1)
  const [checkLoading, setCheckLoading] = useState(false);
  const [logLoading, setLogLoading] = useState(false);
  const [modalVisible, setModalVisible] = useState(false); // 弹窗
  const [content, setContent] = useState(null);
  // 检查数据库表
  useEffect(() => {
    setCheckLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/TableCheck`, {
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        setCheckLoading(false);
        console.log(res);
        if (res.sucess) {
          const { list, messageList } = res;
          // 自动检测列表
          let arr = list.map((item, index) => {
            item.key = index;
            return item;
          });
          // 手动检查列表
          let arr2 = messageList.map((item, index) => {
            item.key = index;
            return item;
          });
          console.log(arr);
          setAutoCheckList(arr);
          setCheckList(arr2);
        }
      })
      .catch(err => {
        setCheckLoading(false);
        console.error(err);
      });
  }, [checkFlag]);
  //获取数据库升级记录
  useEffect(() => {
    setLogLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/DatabaseStandard_GetLog`, {
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        setLogLoading(false);
        console.log(res);
        if (res) {
          let arr = [];
          res.map((item, index) => {
            item.key = index;
            arr.push(item);
          });
          setLogList(res);
        }
      })
      .catch(err => {
        setLogLoading(false);
        console.error(err);
      });
  }, []);
  const handleCheck = () => {
    setCheckFlag(checkFlag+1)
  };
  const handleUpdate = () => {
    alert('updatedb')
    console.log('updatedb');
  };
  const handleLog = text => {
    let arr = []
    arr.push(
      text.split(/[(\r\n)\r\n]+/).map(item =>{
        return (<p>${item}</p>)
      }))
    setModalVisible(true);
    setContent(text);
  };
  const autoCheckColumns = [
    {
      title: '表名称',
      dataIndex: 'tableName',
      key: 'tableName',
    },
    {
      title: '类型',
      dataIndex: 'type',
      key: 'type',
    },
    {
      title: '差异比较',
      dataIndex: 'message',
      key: 'message',
    },
  ];
  const checkColumns = [
    {
      title: '表名称',
      dataIndex: 'tableName',
      key: 'tableName',
      width: 200,
    },
    {
      title: '差异比较',
      dataIndex: 'message',
      key: 'message',
      ellipsis: true,
    },
  ];
  const logColumns = [
    {
      title: '登录名',
      dataIndex: 'updateBy',
      key: 'updateBy',
    },
    {
      title: '数据库名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '数据库版本',
      dataIndex: 'version',
      key: 'version',
    },
    {
      title: '升级时间',
      dataIndex: 'updateTime',
      key: 'updateTime',
    },
    {
      title: '版本日志',
      dataIndex: 'despersion',
      key: 'despersion',
      render: text => {
        return (
          <Button
            size='small'
            onClick={() => {
              handleLog(text);
            }}
          >
            日志
          </Button>
        );
      },
    },
    {
      title: '升级内容',
      dataIndex: 'content',
      key: 'content',
      ellipsis: true,
      render: text => {

        return (
          <Button
            size='small'
            type='primary'
            onClick={() => {
              handleLog(text);
            }}
          >
            升级内容
          </Button>
        );
      },
    },
  ];

  return (
    <>
      <PageContainer>
        <Card>
          <div className={styles.tableTitle}>表结构自动化修复</div>
          <Table
            className={styles.mgTop20}
            columns={autoCheckColumns}
            dataSource={autoCheckList}
            bordered
            loading={checkLoading}
            size='small'
          />
          <div className={ styles.tCenter}>
          <Space>
            <Button  type='primary' onClick={handleCheck} loading={checkLoading}>检查</Button>
            <Button danger type='primary' onClick={handleUpdate}>升级</Button>
          </Space>
          </div>
        </Card>
        <Card className={styles.mgTop20}>
          <div className={styles.tableTitle}>
            表字段手动修复
            (字段长度不统一,请手动修改差异,数据可能会截断,请谨慎操作)
          </div>
          <Table
            className={styles.mgTop20}
            columns={checkColumns}
            dataSource={checkList}
            bordered
            loading={checkLoading}
            size='small'
          />
        </Card>
        <Card className={styles.mgTop20}>
          <div className={styles.tableTitle}>数据库升级记录</div>
          <Table
            className={styles.mgTop20}
            columns={logColumns}
            dataSource={logList}
            bordered
            loading={logLoading}
            size='small'
          />
        </Card>
      </PageContainer>

      <Modal
        title="详细信息"
        visible={modalVisible}
        keyboard={false}
        maskClosable
        onOk={() => setModalVisible(false)}
        onCancel={() => setModalVisible(false)}
        width="1000px"
        bodyStyle={{
          minHeight:'100px',
          maxHeight:'600px',
          overflowY:'scroll'
        }}
        style={{top:"40px"}}
        footer={[
          <Button type='primary' onClick={() => setModalVisible(false)}>关闭窗口</Button>,
        ]}
      >
        {content}
      </Modal>
    </>
  );
};

export default ManagementDataBase;
